@@ -2,6 +2,7 @@
 import fontTools.feaLib.ast as feaast
 import itertools
 from fontFeatures.feaLib.Routine import lookup_type
+import copy
 
 
 def add_language_system_statements(self, ff):
@@ -82,6 +83,17 @@ def asFeaAST(self, do_gdef=True):
     for k,v in self.features.items():
         for reference in v:
             routine = reference.routine
+            # If a rule has >1 language it must first be split
+            newrules = []
+            for r in routine.rules:
+                if len(r.languages or []) > 1:
+                    for language in r.languages:
+                        newrule = copy.copy(r)
+                        newrule.languages = [language]
+                        newrules.append(newrule)
+                else:
+                    newrules.append(r)
+            routine.rules = newrules
             partitioned = self.partitionRoutine(routine,
                 lambda rule:
                     tuple([tuple(rule.languages or []),
@@ -89,28 +101,41 @@ def asFeaAST(self, do_gdef=True):
                     lookup_type(rule)
                     ])
             )
-            if routine.name and len(partitioned) > 1:
+            if routine.name and partitioned and len(partitioned) > 1:
                 for p in partitioned:
                     rule = p.rules[0]
                     language = (rule.languages or [("DFLT", "dflt")])[0]
                     p.name = p.name + "%s_%s_%s_%i" % (
                         language[0].strip(), language[1].strip(), type(rule).__name__, lookup_type(rule)
                     )
+
     for r in self.routines:
         r.usecount = 0
         # Bubble up flags and languages
-        if not r.flags:
+        if r.rules and not r.flags:
             r.flags = r.rules[0].flags
-        if not r.languages:
+        if r.rules and not r.languages:
             r.languages = r.rules[0].languages
 
     for k, v in self.features.items():
+        # Similarly split routines with multiple languages
+        references = []
         for reference in v:
             routine = reference.routine
-            routine.usecount += 1
+            if len(routine.languages or []) > 1:
+                splitroutines = []
+                for language in routine.languages:
+                    # This is wrong. It should really be a new reference to the
+                    # same routine. But this will do for now.
+                    newreference = copy.copy(reference)
+                    newreference.languages = [language]
+                    references.append(newreference)
+            else:
+                references.append(reference)
+                reference.languages = routine.languages
+        self.features[k] = references
         # Order the arranged routines by language
         # new_references = list(sorted(v, key=lambda x: tuple(x.routine.languages or [])))
-        # self.features[k] = new_references
 
     # Next, we'll ensure that all chaining lookups are resolved and in the right order
     newRoutines = [self.routines[i] for i in reorderAndResolve(self)]
@@ -132,13 +157,13 @@ def asFeaAST(self, do_gdef=True):
     ff.statements.append(feaast.Comment(""))
 
     for k in newRoutines:
-        if k.rules and k.usecount != 1:
+        if k.rules:
             ff.statements.append(k.asFeaAST())
 
     for k, v in self.features.items():
         for routine in v:
             # Putting each routine in its own feature saves problems...
-            lang = routine.routine.languages
+            lang = routine.languages
             f = feaast.FeatureBlock(k)
             if lang:
                 f.statements.append(feaast.ScriptStatement(lang[0][0]))
